import os
import shlex
import sys

import xdg.BaseDirectory


def folder() -> str:
    return os.path.join(
        xdg.BaseDirectory.xdg_config_home,
        "hassmpris",
    )


def program() -> str:
    return os.path.join(
        os.path.dirname(__file__),
        "server.py",
    )


def setup_autostart() -> None:
    executable = shlex.quote(sys.executable)
    path = shlex.quote(program())
    text = f"""[Desktop Entry]
Exec={executable} {path}
Type=Application
Terminal=false
"""
    folder = os.path.join(xdg.BaseDirectory.xdg_config_home, "autostart")
    os.makedirs(folder, exist_ok=True)
    with open(os.path.join(folder, "hassmpris-autostart.desktop"), "w") as f:
        f.write(text)


def disable_autostart() -> None:
    folder = os.path.join(xdg.BaseDirectory.xdg_config_home, "autostart")
    f = os.path.join(folder, "hassmpris-autostart.desktop")
    try:
        os.unlink(f)
    except FileNotFoundError:
        pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mpris.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mpris.proto',
  package='MPRIS',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0bmpris.proto\x12\x05MPRIS\x1a\x1bgoogle/protobuf/empty.proto\"\x14\n\x12MPRISUpdateRequest\"u\n\x10MPRISUpdateReply\x12\x11\n\tplayer_id\x18\x01 \x01(\t\x12%\n\x06status\x18\x02 \x01(\x0e\x32\x13.MPRIS.PlayerStatusH\x00\x12\x17\n\rjson_metadata\x18\x03 \x01(\tH\x00\x42\x0e\n\x0cPlayerUpdate\"\xb6\x01\n\x19\x43hangePlayerStatusRequest\x12\x11\n\tplayer_id\x18\x01 \x01(\t\x12?\n\x06status\x18\x02 \x01(\x0e\x32/.MPRIS.ChangePlayerStatusRequest.PlaybackStatus\"E\n\x0ePlaybackStatus\x12\r\n\tUNCHANGED\x10\x00\x12\x0b\n\x07PLAYING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\"\x19\n\x17\x43hangePlayerStatusReply\"&\n\x11PlayerNextRequest\x12\x11\n\tplayer_id\x18\x01 \x01(\t\"\x11\n\x0fPlayerNextReply\"*\n\x15PlayerPreviousRequest\x12\x11\n\tplayer_id\x18\x01 \x01(\t\"\x15\n\x13PlayerPreviousReply*Y\n\x0cPlayerStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04GONE\x10\x01\x12\x0c\n\x08\x41PPEARED\x10\x02\x12\x0b\n\x07PLAYING\x10\x03\x12\n\n\x06PAUSED\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x32\xee\x02\n\x05MPRIS\x12\x38\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12\x41\n\x07Updates\x12\x19.MPRIS.MPRISUpdateRequest\x1a\x17.MPRIS.MPRISUpdateReply\"\x00\x30\x01\x12X\n\x12\x43hangePlayerStatus\x12 .MPRIS.ChangePlayerStatusRequest\x1a\x1e.MPRIS.ChangePlayerStatusReply\"\x00\x12@\n\nPlayerNext\x12\x18.MPRIS.PlayerNextRequest\x1a\x16.MPRIS.PlayerNextReply\"\x00\x12L\n\x0ePlayerPrevious\x12\x1c.MPRIS.PlayerPreviousRequest\x1a\x1a.MPRIS.PlayerPreviousReply\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])

_PLAYERSTATUS = _descriptor.EnumDescriptor(
  name='PlayerStatus',
  full_name='MPRIS.PlayerStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPEARED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAYING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=530,
  serialized_end=619,
)
_sym_db.RegisterEnumDescriptor(_PLAYERSTATUS)

PlayerStatus = enum_type_wrapper.EnumTypeWrapper(_PLAYERSTATUS)
UNKNOWN = 0
GONE = 1
APPEARED = 2
PLAYING = 3
PAUSED = 4
STOPPED = 5


_CHANGEPLAYERSTATUSREQUEST_PLAYBACKSTATUS = _descriptor.EnumDescriptor(
  name='PlaybackStatus',
  full_name='MPRIS.ChangePlayerStatusRequest.PlaybackStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNCHANGED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLAYING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=306,
  serialized_end=375,
)
_sym_db.RegisterEnumDescriptor(_CHANGEPLAYERSTATUSREQUEST_PLAYBACKSTATUS)


_MPRISUPDATEREQUEST = _descriptor.Descriptor(
  name='MPRISUpdateRequest',
  full_name='MPRIS.MPRISUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=71,
)


_MPRISUPDATEREPLY = _descriptor.Descriptor(
  name='MPRISUpdateReply',
  full_name='MPRIS.MPRISUpdateReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='MPRIS.MPRISUpdateReply.player_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='MPRIS.MPRISUpdateReply.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_metadata', full_name='MPRIS.MPRISUpdateReply.json_metadata', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='PlayerUpdate', full_name='MPRIS.MPRISUpdateReply.PlayerUpdate',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=73,
  serialized_end=190,
)


_CHANGEPLAYERSTATUSREQUEST = _descriptor.Descriptor(
  name='ChangePlayerStatusRequest',
  full_name='MPRIS.ChangePlayerStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='MPRIS.ChangePlayerStatusRequest.player_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='MPRIS.ChangePlayerStatusRequest.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANGEPLAYERSTATUSREQUEST_PLAYBACKSTATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=375,
)


_CHANGEPLAYERSTATUSREPLY = _descriptor.Descriptor(
  name='ChangePlayerStatusReply',
  full_name='MPRIS.ChangePlayerStatusReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=402,
)


_PLAYERNEXTREQUEST = _descriptor.Descriptor(
  name='PlayerNextRequest',
  full_name='MPRIS.PlayerNextRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='MPRIS.PlayerNextRequest.player_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=442,
)


_PLAYERNEXTREPLY = _descriptor.Descriptor(
  name='PlayerNextReply',
  full_name='MPRIS.PlayerNextReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=444,
  serialized_end=461,
)


_PLAYERPREVIOUSREQUEST = _descriptor.Descriptor(
  name='PlayerPreviousRequest',
  full_name='MPRIS.PlayerPreviousRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='player_id', full_name='MPRIS.PlayerPreviousRequest.player_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=463,
  serialized_end=505,
)


_PLAYERPREVIOUSREPLY = _descriptor.Descriptor(
  name='PlayerPreviousReply',
  full_name='MPRIS.PlayerPreviousReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=507,
  serialized_end=528,
)

_MPRISUPDATEREPLY.fields_by_name['status'].enum_type = _PLAYERSTATUS
_MPRISUPDATEREPLY.oneofs_by_name['PlayerUpdate'].fields.append(
  _MPRISUPDATEREPLY.fields_by_name['status'])
_MPRISUPDATEREPLY.fields_by_name['status'].containing_oneof = _MPRISUPDATEREPLY.oneofs_by_name['PlayerUpdate']
_MPRISUPDATEREPLY.oneofs_by_name['PlayerUpdate'].fields.append(
  _MPRISUPDATEREPLY.fields_by_name['json_metadata'])
_MPRISUPDATEREPLY.fields_by_name['json_metadata'].containing_oneof = _MPRISUPDATEREPLY.oneofs_by_name['PlayerUpdate']
_CHANGEPLAYERSTATUSREQUEST.fields_by_name['status'].enum_type = _CHANGEPLAYERSTATUSREQUEST_PLAYBACKSTATUS
_CHANGEPLAYERSTATUSREQUEST_PLAYBACKSTATUS.containing_type = _CHANGEPLAYERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['MPRISUpdateRequest'] = _MPRISUPDATEREQUEST
DESCRIPTOR.message_types_by_name['MPRISUpdateReply'] = _MPRISUPDATEREPLY
DESCRIPTOR.message_types_by_name['ChangePlayerStatusRequest'] = _CHANGEPLAYERSTATUSREQUEST
DESCRIPTOR.message_types_by_name['ChangePlayerStatusReply'] = _CHANGEPLAYERSTATUSREPLY
DESCRIPTOR.message_types_by_name['PlayerNextRequest'] = _PLAYERNEXTREQUEST
DESCRIPTOR.message_types_by_name['PlayerNextReply'] = _PLAYERNEXTREPLY
DESCRIPTOR.message_types_by_name['PlayerPreviousRequest'] = _PLAYERPREVIOUSREQUEST
DESCRIPTOR.message_types_by_name['PlayerPreviousReply'] = _PLAYERPREVIOUSREPLY
DESCRIPTOR.enum_types_by_name['PlayerStatus'] = _PLAYERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MPRISUpdateRequest = _reflection.GeneratedProtocolMessageType('MPRISUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _MPRISUPDATEREQUEST,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.MPRISUpdateRequest)
  })
_sym_db.RegisterMessage(MPRISUpdateRequest)

MPRISUpdateReply = _reflection.GeneratedProtocolMessageType('MPRISUpdateReply', (_message.Message,), {
  'DESCRIPTOR' : _MPRISUPDATEREPLY,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.MPRISUpdateReply)
  })
_sym_db.RegisterMessage(MPRISUpdateReply)

ChangePlayerStatusRequest = _reflection.GeneratedProtocolMessageType('ChangePlayerStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPLAYERSTATUSREQUEST,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.ChangePlayerStatusRequest)
  })
_sym_db.RegisterMessage(ChangePlayerStatusRequest)

ChangePlayerStatusReply = _reflection.GeneratedProtocolMessageType('ChangePlayerStatusReply', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPLAYERSTATUSREPLY,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.ChangePlayerStatusReply)
  })
_sym_db.RegisterMessage(ChangePlayerStatusReply)

PlayerNextRequest = _reflection.GeneratedProtocolMessageType('PlayerNextRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERNEXTREQUEST,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.PlayerNextRequest)
  })
_sym_db.RegisterMessage(PlayerNextRequest)

PlayerNextReply = _reflection.GeneratedProtocolMessageType('PlayerNextReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERNEXTREPLY,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.PlayerNextReply)
  })
_sym_db.RegisterMessage(PlayerNextReply)

PlayerPreviousRequest = _reflection.GeneratedProtocolMessageType('PlayerPreviousRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERPREVIOUSREQUEST,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.PlayerPreviousRequest)
  })
_sym_db.RegisterMessage(PlayerPreviousRequest)

PlayerPreviousReply = _reflection.GeneratedProtocolMessageType('PlayerPreviousReply', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERPREVIOUSREPLY,
  '__module__' : 'mpris_pb2'
  # @@protoc_insertion_point(class_scope:MPRIS.PlayerPreviousReply)
  })
_sym_db.RegisterMessage(PlayerPreviousReply)



_MPRIS = _descriptor.ServiceDescriptor(
  name='MPRIS',
  full_name='MPRIS.MPRIS',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=622,
  serialized_end=988,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='MPRIS.MPRIS.Ping',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Updates',
    full_name='MPRIS.MPRIS.Updates',
    index=1,
    containing_service=None,
    input_type=_MPRISUPDATEREQUEST,
    output_type=_MPRISUPDATEREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangePlayerStatus',
    full_name='MPRIS.MPRIS.ChangePlayerStatus',
    index=2,
    containing_service=None,
    input_type=_CHANGEPLAYERSTATUSREQUEST,
    output_type=_CHANGEPLAYERSTATUSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PlayerNext',
    full_name='MPRIS.MPRIS.PlayerNext',
    index=3,
    containing_service=None,
    input_type=_PLAYERNEXTREQUEST,
    output_type=_PLAYERNEXTREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PlayerPrevious',
    full_name='MPRIS.MPRIS.PlayerPrevious',
    index=4,
    containing_service=None,
    input_type=_PLAYERPREVIOUSREQUEST,
    output_type=_PLAYERPREVIOUSREPLY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MPRIS)

DESCRIPTOR.services_by_name['MPRIS'] = _MPRIS

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from hassmpris.proto import mpris_pb2 as mpris__pb2


class MPRISStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/MPRIS.MPRIS/Ping',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.Updates = channel.unary_stream(
                '/MPRIS.MPRIS/Updates',
                request_serializer=mpris__pb2.MPRISUpdateRequest.SerializeToString,
                response_deserializer=mpris__pb2.MPRISUpdateReply.FromString,
                )
        self.ChangePlayerStatus = channel.unary_unary(
                '/MPRIS.MPRIS/ChangePlayerStatus',
                request_serializer=mpris__pb2.ChangePlayerStatusRequest.SerializeToString,
                response_deserializer=mpris__pb2.ChangePlayerStatusReply.FromString,
                )
        self.PlayerNext = channel.unary_unary(
                '/MPRIS.MPRIS/PlayerNext',
                request_serializer=mpris__pb2.PlayerNextRequest.SerializeToString,
                response_deserializer=mpris__pb2.PlayerNextReply.FromString,
                )
        self.PlayerPrevious = channel.unary_unary(
                '/MPRIS.MPRIS/PlayerPrevious',
                request_serializer=mpris__pb2.PlayerPreviousRequest.SerializeToString,
                response_deserializer=mpris__pb2.PlayerPreviousReply.FromString,
                )


class MPRISServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Updates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePlayerStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayerNext(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlayerPrevious(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MPRISServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'Updates': grpc.unary_stream_rpc_method_handler(
                    servicer.Updates,
                    request_deserializer=mpris__pb2.MPRISUpdateRequest.FromString,
                    response_serializer=mpris__pb2.MPRISUpdateReply.SerializeToString,
            ),
            'ChangePlayerStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePlayerStatus,
                    request_deserializer=mpris__pb2.ChangePlayerStatusRequest.FromString,
                    response_serializer=mpris__pb2.ChangePlayerStatusReply.SerializeToString,
            ),
            'PlayerNext': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayerNext,
                    request_deserializer=mpris__pb2.PlayerNextRequest.FromString,
                    response_serializer=mpris__pb2.PlayerNextReply.SerializeToString,
            ),
            'PlayerPrevious': grpc.unary_unary_rpc_method_handler(
                    servicer.PlayerPrevious,
                    request_deserializer=mpris__pb2.PlayerPreviousRequest.FromString,
                    response_serializer=mpris__pb2.PlayerPreviousReply.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'MPRIS.MPRIS', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MPRIS(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/Ping',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Updates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/MPRIS.MPRIS/Updates',
            mpris__pb2.MPRISUpdateRequest.SerializeToString,
            mpris__pb2.MPRISUpdateReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePlayerStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/ChangePlayerStatus',
            mpris__pb2.ChangePlayerStatusRequest.SerializeToString,
            mpris__pb2.ChangePlayerStatusReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayerNext(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/PlayerNext',
            mpris__pb2.PlayerNextRequest.SerializeToString,
            mpris__pb2.PlayerNextReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PlayerPrevious(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/MPRIS.MPRIS/PlayerPrevious',
            mpris__pb2.PlayerPreviousRequest.SerializeToString,
            mpris__pb2.PlayerPreviousReply.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
